@@ -355,12 +355,6 @@ class (FoldableLL full item, Monoid full) =>
          of the item.  This can have performance benefits with some types. -}
     rigidMapM :: Monad m => (item -> m item) -> full -> m full
     rigidMapM = mapM
-            
-    {- | A map in monad space, discarding results.  Same as
-       @'sequence_' . 'map'@ -}
-    mapM_ :: (Monad m) => (item -> m b) -> full -> m ()
-    mapM_ func l = sequence_ mapresult
-            where mapresult = asTypeOf (map func l) []
 
 
     ------------------------------ "Set" operations
@@ -604,7 +598,6 @@ instance ListLike [a] a where
     findIndex = L.findIndex
     sequence = M.sequence . toList
     -- mapM = M.mapM
-    mapM_ = M.mapM_
     nub = L.nub
     delete = L.delete
     deleteFirsts = (L.\\)
@@ -639,9 +632,3 @@ zipWith f a b
     | null a = empty
     | null b = empty
     | otherwise = cons (f (head a) (head b)) (zipWith f (tail a) (tail b))
-
-{- | Evaluate each action, ignoring the results -}
-sequence_ :: (Monad m, ListLike mfull (m item)) => mfull -> m ()
-sequence_ l = foldr (>>) (return ()) l
-
-
